/*
 * \file SHIS_Ifg2SpectrumTest.cc
 * \brief unit test for SHISStage subclass of Ifg2SpectrumStage
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: SHIS_Ifg2SpectrumTest.cc,v 1.7 2004/10/07 15:53:33 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

// how to test the nonlinearity correction operator?
// for one thing, we need some ersatz connectors that provide
// data from a compile-time allocated memory cache, and read back
// into another one (at least for the unit tests)

#include <iostream> // std::cerr
#include <cstring> // memset
#include <cstdlib> // exit
#include <cassert> // assert


#include "Ifg2Spectrum.h"
#include "Instrument.h"
#include "TestConnector.h"
#include "Operator.h"

namespace Ifg2Spectrum
{
    
Operator::Result testOperator( )
{

    // data in & out
    TestConnector::ZeroFilledInputPort< Instrument::BlitzCplxDoubleVector > testIn;
    TestConnector::NoDownstreamCZ1024Connector< Instrument::BlitzCplxDoubleVector > testOut;
    
    // configuration - used at initialization of stage and operators
    Config_t defaultConfig( 1024, 512 );
    Connector::ConstantInputPort< Config_t > testConfig( defaultConfig );
    
    Ports ports( testIn, testOut, testConfig );

    Ifg2SpectrumStage *stageptr = Ifg2SpectrumStage::Factory( Instrument::SHIS, ports );
    //Ifg2SpectrumStage &stage( *stageptr ); // local name to avoid using pointer syntax
    Operator::Result res = stageptr->operator()( );
    
    return res;
}; // testOperator()

}; // namespace


int main( int argc, char *argv[] )
{
    Operator::Result rc = Ifg2Spectrum::testOperator();
    assert( rc==Operator::OK );
    exit(0);
}
